Stan Math Library: stan/math/prim/scal/prob/frechet_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

frechet_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_FRECHET_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_FRECHET_RNG_HPP
3
4 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
5 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
6 #include <stan/math/prim/scal/err/check_not_nan.hpp>
7 #include <stan/math/prim/scal/err/check_positive.hpp>
8 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
9 #include <stan/math/prim/scal/fun/log1m.hpp>
10 #include <stan/math/prim/scal/fun/multiply_log.hpp>
11 #include <stan/math/prim/scal/fun/value_of.hpp>
12 #include <stan/math/prim/scal/meta/length.hpp>
13 #include <stan/math/prim/scal/meta/VectorView.hpp>
14 #include <stan/math/prim/scal/meta/VectorBuilder.hpp>
15 #include <stan/math/prim/scal/meta/return_type.hpp>
16 #include <stan/math/prim/scal/fun/constants.hpp>
17 #include <stan/math/prim/scal/meta/include_summand.hpp>
18 #include <boost/random/weibull_distribution.hpp>
19 #include <boost/random/variate_generator.hpp>
20
21 namespace stan {
22
23 namespace math {
24
25 template <class RNG>
26 inline double
27 frechet_rng(const double alpha,
28 const double sigma,
29 RNG& rng) {
30 using boost::variate_generator;
31 using boost::random::weibull_distribution;
32
33 static const char* function("stan::math::frechet_rng");
34
35 using stan::math::check_finite;
36 using stan::math::check_not_nan;
37 using stan::math::check_positive;
38
39 check_finite(function, "Shape parameter", alpha);
40 check_positive(function, "Shape parameter", alpha);
41 check_not_nan(function, "Scale parameter", sigma);
42 check_positive(function, "Scale parameter", sigma);
43
44 variate_generator<RNG&, weibull_distribution<> >
45 weibull_rng(rng, weibull_distribution<>(alpha, 1.0/sigma));
46 return 1.0 / weibull_rng();
47 }
48 }
49 }
50 #endif
check_not_nan.hpp
stan::math::check_not_nan
bool check_not_nan(const char *function, const char *name, const T_y &y)
Return true if y is not NaN.
Definition: check_not_nan.hpp:63
check_positive_finite.hpp
check_positive.hpp
stan
Definition: log_sum_exp.hpp:8
return_type.hpp
include_summand.hpp
multiply_log.hpp
check_nonnegative.hpp
stan::math::frechet_rng
double frechet_rng(const double alpha, const double sigma, RNG &rng)
Definition: frechet_rng.hpp:27
VectorView.hpp
stan::math::check_positive
bool check_positive(const char *function, const char *name, const T_y &y)
Return true if y is positive.
Definition: check_positive.hpp:68
VectorBuilder.hpp
log1m.hpp
stan::math::weibull_rng
double weibull_rng(const double alpha, const double sigma, RNG &rng)
Definition: weibull_rng.hpp:23
length.hpp
stan::math::check_finite
bool check_finite(const char *function, const char *name, const T_y &y)
Return true if y is finite.
Definition: check_finite.hpp:62
constants.hpp
value_of.hpp
check_consistent_sizes.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.